@@ -80,8 +80,7 @@ class AvroJsonConverter(object):
             return True in [self.validate(s, datum, skip_logical_types) for s in expected_schema.schemas]
         elif schema_type in ['record', 'error', 'request']:
             return ((isinstance(datum, dict) or isinstance(datum, DictWrapper)) and
-                    False not in
-                    [self.validate(f.type, datum.get(f.name), skip_logical_types) for f in expected_schema.fields])
+                    all(self.validate(f.type, datum.get(f.name, f.default) if f.has_default else datum.get(f.name), skip_logical_types) for f in expected_schema.fields))
         elif not self.fastavro and schema_type == 'bytes':
             # Specialization for bytes, which are encoded as strings in JSON.
             if isinstance(datum, str):
@@ -176,10 +175,19 @@ class AvroJsonConverter(object):
         result = collections.OrderedDict()
 
         for field in writers_schema.fields:
-            result[field.name] = self._generic_to_json(
-                data_obj.get(field.name,
-                             self.from_json_object(field.default, field.type) if field.has_default else None),
-                field.type)
+            if field.has_default:
+                default = self.from_json_object(field.default, field.type)
+                obj = data_obj.get(field.name, default)
+
+                if obj is None and default is None:
+                    # If the field's defaults to none and the current value is none,
+                    # then we can skip emitting this field since the consumer will
+                    # automatically fill it.
+                    continue
+            else:
+                obj = data_obj.get(field.name)
+
+            result[field.name] = self._generic_to_json(obj, field.type)
         return result
     
     def _is_unambiguous_union(self, writers_schema) -> bool:
@@ -293,10 +301,9 @@ class AvroJsonConverter(object):
         value = None
         if not self.fastavro and isinstance(json_obj, dict):
             items = list(six.iteritems(json_obj))
-            if not items:
-                return None
-            value_type = items[0][0]
-            value = items[0][1]
+            if len(items) == 1:
+                value_type = items[0][0]
+                value = items[0][1]
         if self.fastavro and (isinstance(json_obj, list) or isinstance(json_obj, tuple)):
             if len(json_obj) == 2:
                 value_type = json_obj[0]
